summaryrefslogtreecommitdiff
path: root/pkg/specgen
diff options
context:
space:
mode:
authorJhon Honce <jhonce@redhat.com>2020-04-15 10:12:30 -0700
committerJhon Honce <jhonce@redhat.com>2020-04-16 11:08:08 -0700
commit1d93d212541616135da23bcf01ca49180f113e62 (patch)
treee75553459f315d69904d6b1687a1423d0825e219 /pkg/specgen
parent5def21140038fc34cee9707d3069bf52adc24577 (diff)
downloadpodman-1d93d212541616135da23bcf01ca49180f113e62.tar.gz
podman-1d93d212541616135da23bcf01ca49180f113e62.tar.bz2
podman-1d93d212541616135da23bcf01ca49180f113e62.zip
V2 Enable rootless
* Enable running podman V2 rootless * Fixed cobra.PersistentPreRunE usage in all the commands * Leveraged cobra.PersistentPreRunE/cobra.PersistentPostRunE to manage: * rootless * trace (--trace) * profiling (--cpu-profile) * initializing the registry copies of Image/Container engines * Help and Usage templates autoset for all sub-commands Signed-off-by: Jhon Honce <jhonce@redhat.com>
Diffstat (limited to 'pkg/specgen')
-rw-r--r--pkg/specgen/namespaces.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/specgen/namespaces.go b/pkg/specgen/namespaces.go
index 2ef5bc229..2e7f80fe8 100644
--- a/pkg/specgen/namespaces.go
+++ b/pkg/specgen/namespaces.go
@@ -28,9 +28,9 @@ const (
// Bridge indicates that a CNI network stack
// should be used
Bridge NamespaceMode = "bridge"
// Slirp indicates that a slirp4ns network stack should
// be used
- Slirp NamespaceMode = "slirp4ns"
+ Slirp NamespaceMode = "slirp4netns"
)
// Namespace describes the namespace
@@ -28,9 +28,9 @@ const (
// should be used
Bridge NamespaceMode = "bridge"
- // Slirp indicates that a slirp4ns network stack should
+ // Slirp indicates that a slirp4netns network stack should
// be used